# Advanced Concepts

The Artifician library is designed to be easy to use for simple tasks,
yet flexible enough for complex data preparation workflows. In this
section, we will delve into the more advanced features and architectural
choices that power the Artifician library.

## Table of Contents

::: {.toctree maxdepth="3"}
define_extractors define_processor library_architecture
:::

Whether you\'re looking to extend the library\'s capabilities or trying
to get a deeper understanding of how things work, these advanced topics
will provide you with the knowledge you need.
